<?php
/**
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace OCA\SideMenu\Controller;

use OCP\AppFramework\Controller;
use OCP\AppFramework\Http\DataDownloadResponse;
use OCP\AppFramework\Http\Response;
use OCP\IConfig;
use OCP\IRequest;

class CssController extends Controller
{

    /** @var \OCP\IConfig */
    protected $config;

    /**
     * @param string $appName
     * @param IRequest $request
     * @param IConfig $config
     */
    public function __construct($appName, IRequest $request, IConfig $config)
    {
        parent::__construct($appName, $request);
        $this->config = $config;
    }

    /**
     * @NoAdminRequired
     * @NoCSRFRequired
     * @PublicPage
     *
     * @return Response
     */
    public function stylesheet()
    {
        $parameters = [
            '--side-menu-background-color' => $this->config->getAppValue('side_menu', 'background-color', '#333333'),
            '--side-menu-current-app-background-color' => $this->config->getAppValue('side_menu', 'current-app-background-color', '#444444'),
            '--side-menu-text-color' => $this->config->getAppValue('side_menu', 'text-color', '#FFFFFF'),
            '--side-menu-opener' => $this->config->getAppValue('side_menu', 'opener', 'side-menu-opener'),
        ];

        $css = '';

        foreach ($parameters as $key => $value) {
            if ($key === '--side-menu-opener') {
                $value = sprintf("url('../img/%s.svg')", $value);
            }

            $css.= sprintf('%s: %s;', $key, $value);
        }

        $css = sprintf(':root { %s }', $css);

        return new DataDownloadResponse($css, 'stylesheet', 'text/css');
    }
}
