<?php
/**
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace OCA\SideMenu\Settings;

use OCP\AppFramework\Http\TemplateResponse;
use OCP\IL10N;
use OCP\ILogger;
use OCP\Settings\ISettings;
use OCP\IConfig;

class Admin implements ISettings
{
    /** @var IL10N */
    private $l;

    /** @var ILogger */
    private $logger;

    /** @var IConfig */
    private $config;

    public function __construct(IL10N $l, ILogger $logger, IConfig $config)
    {
        $this->l = $l;
        $this->logger = $logger;
        $this->config = $config;
    }

    /**
     * @return TemplateResponse
     */
    public function getForm()
    {
        $parameters = [
            'background-color' => $this->config->getAppValue('side_menu', 'background-color', '#333333'),
            'current-app-background-color' => $this->config->getAppValue('side_menu', 'current-app-background-color', '#444444'),
            'text-color' => $this->config->getAppValue('side_menu', 'text-color', '#FFFFFF'),
            'cache' => $this->config->getAppValue('side_menu', 'cache', '0'),
            'opener' => $this->config->getAppValue('side_menu', 'opener', 'side-menu-opener'),
        ];

        return new TemplateResponse('side_menu', 'settings/admin-form', $parameters, '');
    }

    /**
     * @return string the section ID, e.g. 'sharing'
     */
    public function getSection()
    {
        return 'side_menu';
    }

    /**
     * @return int whether the form should be rather on the top or bottom of
     * the admin section. The forms are arranged in ascending order of the
     * priority values. It is required to return a value between 0 and 100.
     *
     * E.g.: 70
     */
    public function getPriority()
    {
        return 70;
    }
}
